@@ -1,33 +1,23 @@
 from __future__ import annotations
-from pathlib import _PosixFlavour, _WindowsFlavour
-from typing import Optional, Callable, Awaitable, Dict, List, TYPE_CHECKING
-from errno import EINVAL
+
 import os
-import sys
-from .aiopathz.wrap import func_to_async_func as wrap_async
 
-try:
-    from pathlib import _getfinalpathname
-    _async_getfinalpathname = wrap_async(_getfinalpathname)
+from errno import EINVAL
+from typing import Optional, Callable, Awaitable, Dict, List, TYPE_CHECKING
 
-except ImportError:
-    def _getfinalpathname(*args, **kwargs):
-        raise ImportError("_getfinalpathname() requires a Windows/NT platform")
-
-    async def _async_getfinalpathname(*args, **kwargs):
-        raise ImportError("_getfinalpathname() requires a Windows/NT platform")
+from .base_imports import _PosixFlavour, _WindowsFlavour, _getfinalpathname, _async_getfinalpathname, func_to_async_func
 
 if TYPE_CHECKING:  # keep mypy quiet
     from .base import PathzPath, _PathzAccessor
 
 
-class _AsyncSyncPosixFlavour(_PosixFlavour):
+class _PathzPosixFlavour(_PosixFlavour):
     
     def gethomedir(self, username: str) -> str:
         return super().gethomedir(username)
 
     async def async_gethomedir(self, username: str) -> str:
-        gethomedir: Callable[[str], Awaitable[str]] = wrap_async(super().gethomedir)
+        gethomedir: Callable[[str], Awaitable[str]] = func_to_async_func(super().gethomedir)
         return await gethomedir(username)
 
     def resolve(self, path: PathzPath, strict: bool = False) -> Optional[str]:
@@ -123,12 +113,12 @@ class _AsyncSyncPosixFlavour(_PosixFlavour):
         return result or sep
 
 
-class _AsyncSyncWindowsFlavour(_WindowsFlavour):
+class _PathzWindowsFlavour(_WindowsFlavour):
     def gethomedir(self, username: str) -> str: 
         return super().gethomedir(username)
 
     async def async_gethomedir(self, username: str) -> str: 
-        gethomedir: Callable[[str], Awaitable[str]] = wrap_async(super().gethomedir)
+        gethomedir: Callable[[str], Awaitable[str]] = func_to_async_func(super().gethomedir)
         return await gethomedir(username)
 
     def resolve(self, path: 'PathzPath', strict: bool = False) -> Optional[str]:
@@ -174,5 +164,5 @@ class _AsyncSyncWindowsFlavour(_WindowsFlavour):
         return None
 
 
-_async_sync_windows_flavour = _AsyncSyncWindowsFlavour()
-_async_sync_posix_flavour = _AsyncSyncPosixFlavour()
+_pathz_windows_flavour = _PathzWindowsFlavour()
+_pathz_posix_flavour = _PathzPosixFlavour()
